@@ -126,10 +126,6 @@ namespace Oxygen
         hide();
     }
 
-    //____________________________________________________________________
-    SplitterProxy::~SplitterProxy( void )
-    {}
-
     //____________________________________________________________________
     void SplitterProxy::setEnabled( bool value )
     {
